# compass.api_client


#### Welcome to the DeFi API from [Compass Labs](https://www.compasslabs.ai)!

Our API allows you to interact and transact in DeFi with ease.

We help you construct your transactions via a **simple REST API**.  
You maintain custody at all times and **sign** all transactions **yourself**.

Below is the documentation of our endpoints. It's a great first step to explore.



---

**Try out our [App](https://api-app.compasslabs.ai/) built on top of the API!**

---

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.0.1
- Package version: 1.0.0
- Generator version: 7.12.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.compasslabs.ai/](https://www.compasslabs.ai/)

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import compass.api_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import compass.api_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import compass.api_client
from compass.api_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.compasslabs.ai
# See configuration.py for a list of all supported configuration parameters.
configuration = compass.api_client.Configuration(
    host = "https://api.compasslabs.ai"
)



# Enter a context with an instance of the API client
with compass.api_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = compass.api_client.AaveV3Api(api_client)
    chain = compass.api_client.Chain() # Chain | 
    aave_get_asset_price = compass.api_client.AaveGetAssetPrice() # AaveGetAssetPrice | 

    try:
        # Get the price of an asset in USD according to Aave
        api_response = api_instance.process_request_v0_aave_asset_price_get_chain_post(chain, aave_get_asset_price)
        print("The response of AaveV3Api->process_request_v0_aave_asset_price_get_chain_post:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AaveV3Api->process_request_v0_aave_asset_price_get_chain_post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.compasslabs.ai*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AaveV3Api* | [**process_request_v0_aave_asset_price_get_chain_post**](docs/AaveV3Api.md#process_request_v0_aave_asset_price_get_chain_post) | **POST** /v0/aave/asset_price/get/{chain} | Get the price of an asset in USD according to Aave
*AaveV3Api* | [**process_request_v0_aave_borrow_chain_post**](docs/AaveV3Api.md#process_request_v0_aave_borrow_chain_post) | **POST** /v0/aave/borrow/{chain} | Borrow against your collateral
*AaveV3Api* | [**process_request_v0_aave_repay_chain_post**](docs/AaveV3Api.md#process_request_v0_aave_repay_chain_post) | **POST** /v0/aave/repay/{chain} | Return some or all tokens you borrowed
*AaveV3Api* | [**process_request_v0_aave_supply_chain_post**](docs/AaveV3Api.md#process_request_v0_aave_supply_chain_post) | **POST** /v0/aave/supply/{chain} | Supply collateral to earn interest or borrow against
*AaveV3Api* | [**process_request_v0_aave_user_position_per_token_get_chain_post**](docs/AaveV3Api.md#process_request_v0_aave_user_position_per_token_get_chain_post) | **POST** /v0/aave/user_position_per_token/get/{chain} | Get the user&#39;s position for a specific token.
*AaveV3Api* | [**process_request_v0_aave_user_position_summary_get_chain_post**](docs/AaveV3Api.md#process_request_v0_aave_user_position_summary_get_chain_post) | **POST** /v0/aave/user_position_summary/get/{chain} | Get a summary of the user&#39;s position on AAVE. These values will be sums or averages across all open positions.
*AaveV3Api* | [**process_request_v0_aave_withdraw_chain_post**](docs/AaveV3Api.md#process_request_v0_aave_withdraw_chain_post) | **POST** /v0/aave/withdraw/{chain} | Withdraw some or all of your collateral
*AerodromeApi* | [**process_request_v0_aerodrome_liquidity_provision_add_liquidity_chain_post**](docs/AerodromeApi.md#process_request_v0_aerodrome_liquidity_provision_add_liquidity_chain_post) | **POST** /v0/aerodrome/liquidity_provision/add_liquidity/{chain} | Provide liquidity to a pool on Aerodrome
*AerodromeApi* | [**process_request_v0_aerodrome_liquidity_provision_add_liquidity_eth_chain_post**](docs/AerodromeApi.md#process_request_v0_aerodrome_liquidity_provision_add_liquidity_eth_chain_post) | **POST** /v0/aerodrome/liquidity_provision/add_liquidity_eth/{chain} | Provide liquidity to a pool on Aerodrome using WETH and another token
*AerodromeApi* | [**process_request_v0_aerodrome_liquidity_provision_remove_liquidity_chain_post**](docs/AerodromeApi.md#process_request_v0_aerodrome_liquidity_provision_remove_liquidity_chain_post) | **POST** /v0/aerodrome/liquidity_provision/remove_liquidity/{chain} | Remove liquidity from a pool on Aerodrome
*AerodromeApi* | [**process_request_v0_aerodrome_liquidity_provision_remove_liquidity_eth_chain_post**](docs/AerodromeApi.md#process_request_v0_aerodrome_liquidity_provision_remove_liquidity_eth_chain_post) | **POST** /v0/aerodrome/liquidity_provision/remove_liquidity_eth/{chain} | Remove liquidity from a pool on Aerodrome using WETH and another token
*AerodromeApi* | [**process_request_v0_aerodrome_swap_eth_for_token_chain_post**](docs/AerodromeApi.md#process_request_v0_aerodrome_swap_eth_for_token_chain_post) | **POST** /v0/aerodrome/swap/eth_for_token/{chain} | Swap ETH for some of a token on Aerodrome
*AerodromeApi* | [**process_request_v0_aerodrome_swap_token_for_eth_chain_post**](docs/AerodromeApi.md#process_request_v0_aerodrome_swap_token_for_eth_chain_post) | **POST** /v0/aerodrome/swap/token_for_eth/{chain} | Swap a token for ETH on Aerodrome
*AerodromeApi* | [**process_request_v0_aerodrome_swap_tokens_chain_post**](docs/AerodromeApi.md#process_request_v0_aerodrome_swap_tokens_chain_post) | **POST** /v0/aerodrome/swap/tokens/{chain} | Swap one token for another token on Aerodrome
*OthersApi* | [**get_tokens_v0_generic_tokens_get_chain_post**](docs/OthersApi.md#get_tokens_v0_generic_tokens_get_chain_post) | **POST** /v0/generic/tokens/get/{chain} | Get Tokens
*OthersApi* | [**process_request_v0_generic_allowance_get_chain_post**](docs/OthersApi.md#process_request_v0_generic_allowance_get_chain_post) | **POST** /v0/generic/allowance/get/{chain} | Show the allowance of a user on a protocol
*OthersApi* | [**process_request_v0_generic_allowance_set_any_chain_post**](docs/OthersApi.md#process_request_v0_generic_allowance_set_any_chain_post) | **POST** /v0/generic/allowance/set_any/{chain} | Sets allowance for any arbitrary ERC20 token address.
*OthersApi* | [**process_request_v0_generic_allowance_set_chain_post**](docs/OthersApi.md#process_request_v0_generic_allowance_set_chain_post) | **POST** /v0/generic/allowance/set/{chain} | Change the allowance of a user on a protocol
*OthersApi* | [**process_request_v0_generic_balance_get_chain_post**](docs/OthersApi.md#process_request_v0_generic_balance_get_chain_post) | **POST** /v0/generic/balance/get/{chain} | Get an address balance of a token
*OthersApi* | [**process_request_v0_generic_ens_get_chain_post**](docs/OthersApi.md#process_request_v0_generic_ens_get_chain_post) | **POST** /v0/generic/ens/get/{chain} | Get the wallet address and registrant of an ENS name
*OthersApi* | [**process_request_v0_generic_portfolio_get_chain_post**](docs/OthersApi.md#process_request_v0_generic_portfolio_get_chain_post) | **POST** /v0/generic/portfolio/get/{chain} | Get the portfolio details for a wallet address including balances and values of all tokens.
*OthersApi* | [**process_request_v0_generic_visualize_portfolio_get_chain_post**](docs/OthersApi.md#process_request_v0_generic_visualize_portfolio_get_chain_post) | **POST** /v0/generic/visualize_portfolio/get/{chain} | Visualize the token portfolio of a wallet address as a pie chart
*OthersApi* | [**process_request_v0_generic_wrap_eth_chain_post**](docs/OthersApi.md#process_request_v0_generic_wrap_eth_chain_post) | **POST** /v0/generic/wrap_eth/{chain} | Change raw ETH into WETH
*UniswapV3Api* | [**process_request_v0_uniswap_liquidity_provision_increase_chain_post**](docs/UniswapV3Api.md#process_request_v0_uniswap_liquidity_provision_increase_chain_post) | **POST** /v0/uniswap/liquidity_provision/increase/{chain} | Increase an LP position
*UniswapV3Api* | [**process_request_v0_uniswap_liquidity_provision_mint_chain_post**](docs/UniswapV3Api.md#process_request_v0_uniswap_liquidity_provision_mint_chain_post) | **POST** /v0/uniswap/liquidity_provision/mint/{chain} | Open a new LP position
*UniswapV3Api* | [**process_request_v0_uniswap_liquidity_provision_positions_get_chain_post**](docs/UniswapV3Api.md#process_request_v0_uniswap_liquidity_provision_positions_get_chain_post) | **POST** /v0/uniswap/liquidity_provision/positions/get/{chain} | Get the number of LP positions for a given sender
*UniswapV3Api* | [**process_request_v0_uniswap_liquidity_provision_withdraw_chain_post**](docs/UniswapV3Api.md#process_request_v0_uniswap_liquidity_provision_withdraw_chain_post) | **POST** /v0/uniswap/liquidity_provision/withdraw/{chain} | Withdraw a LP position
*UniswapV3Api* | [**process_request_v0_uniswap_pool_price_get_chain_post**](docs/UniswapV3Api.md#process_request_v0_uniswap_pool_price_get_chain_post) | **POST** /v0/uniswap/pool_price/get/{chain} | Get the current price of a pool (how many token0 you can buy for 1 token1). This is only the instantaneous price; during any trade the price will change. Use the quote endpoint to get a more realistic idea of the ratios of the two assets you could trade.
*UniswapV3Api* | [**process_request_v0_uniswap_quote_buy_exactly_get_chain_post**](docs/UniswapV3Api.md#process_request_v0_uniswap_quote_buy_exactly_get_chain_post) | **POST** /v0/uniswap/quote/buy_exactly/get/{chain} | Get the amount of tokens you would need to provide to the pool in order to purchase a fixed quantity of tokens. Also returns what the price would be afterwards.
*UniswapV3Api* | [**process_request_v0_uniswap_quote_sell_exactly_get_chain_post**](docs/UniswapV3Api.md#process_request_v0_uniswap_quote_sell_exactly_get_chain_post) | **POST** /v0/uniswap/quote/sell_exactly/get/{chain} | Get the amount of tokens you would get from the pool if you provided a fixed quantity of tokens. Also returns what the price would be afterwards.
*UniswapV3Api* | [**process_request_v0_uniswap_swap_buy_exactly_chain_post**](docs/UniswapV3Api.md#process_request_v0_uniswap_swap_buy_exactly_chain_post) | **POST** /v0/uniswap/swap/buy_exactly/{chain} | Trade the amount of a token it takes to end up with a specified quantity of the other token
*UniswapV3Api* | [**process_request_v0_uniswap_swap_sell_exactly_chain_post**](docs/UniswapV3Api.md#process_request_v0_uniswap_swap_sell_exactly_chain_post) | **POST** /v0/uniswap/swap/sell_exactly/{chain} | Trade a specific amount of a token into another.


## Documentation For Models

 - [AaveAssetPriceInfo](docs/AaveAssetPriceInfo.md)
 - [AaveBorrowCallData](docs/AaveBorrowCallData.md)
 - [AaveGetAssetPrice](docs/AaveGetAssetPrice.md)
 - [AaveGetUserPositionPerToken](docs/AaveGetUserPositionPerToken.md)
 - [AaveGetUserPositionSummary](docs/AaveGetUserPositionSummary.md)
 - [AaveRepayCallData](docs/AaveRepayCallData.md)
 - [AaveSupplyCallData](docs/AaveSupplyCallData.md)
 - [AaveUserPositionPerTokenInfo](docs/AaveUserPositionPerTokenInfo.md)
 - [AaveUserPositionSummaryInfo](docs/AaveUserPositionSummaryInfo.md)
 - [AaveWithdrawCallData](docs/AaveWithdrawCallData.md)
 - [AeroLiquidityProvisionCallData](docs/AeroLiquidityProvisionCallData.md)
 - [AeroLiquidityProvisionEthCallData](docs/AeroLiquidityProvisionEthCallData.md)
 - [AeroRemoveLiquidityCallData](docs/AeroRemoveLiquidityCallData.md)
 - [AeroRemoveLiquidityEthCallData](docs/AeroRemoveLiquidityEthCallData.md)
 - [AeroSwapEthForTokenCallData](docs/AeroSwapEthForTokenCallData.md)
 - [AeroSwapTokenForEthCallData](docs/AeroSwapTokenForEthCallData.md)
 - [AeroSwapTokensCallData](docs/AeroSwapTokensCallData.md)
 - [AllowanceInfo](docs/AllowanceInfo.md)
 - [Amount](docs/Amount.md)
 - [Amount0Desired](docs/Amount0Desired.md)
 - [Amount0Min](docs/Amount0Min.md)
 - [Amount1](docs/Amount1.md)
 - [Amount1Desired](docs/Amount1Desired.md)
 - [Amount1Min](docs/Amount1Min.md)
 - [Amount2](docs/Amount2.md)
 - [Amount3](docs/Amount3.md)
 - [Amount4](docs/Amount4.md)
 - [AmountADesired](docs/AmountADesired.md)
 - [AmountAMin](docs/AmountAMin.md)
 - [AmountAMin1](docs/AmountAMin1.md)
 - [AmountBDesired](docs/AmountBDesired.md)
 - [AmountBMin](docs/AmountBMin.md)
 - [AmountBMin1](docs/AmountBMin1.md)
 - [AmountEthDesired](docs/AmountEthDesired.md)
 - [AmountEthMin](docs/AmountEthMin.md)
 - [AmountEthMin1](docs/AmountEthMin1.md)
 - [AmountIn](docs/AmountIn.md)
 - [AmountIn1](docs/AmountIn1.md)
 - [AmountIn2](docs/AmountIn2.md)
 - [AmountInMaximum](docs/AmountInMaximum.md)
 - [AmountOut](docs/AmountOut.md)
 - [AmountOutMin](docs/AmountOutMin.md)
 - [AmountOutMin1](docs/AmountOutMin1.md)
 - [AmountOutMinimum](docs/AmountOutMinimum.md)
 - [AmountTokenDesired](docs/AmountTokenDesired.md)
 - [AmountTokenMin](docs/AmountTokenMin.md)
 - [AmountTokenMin1](docs/AmountTokenMin1.md)
 - [BalanceInfo](docs/BalanceInfo.md)
 - [BaseTransactionRequestAaveBorrowCallData](docs/BaseTransactionRequestAaveBorrowCallData.md)
 - [BaseTransactionRequestAaveRepayCallData](docs/BaseTransactionRequestAaveRepayCallData.md)
 - [BaseTransactionRequestAaveSupplyCallData](docs/BaseTransactionRequestAaveSupplyCallData.md)
 - [BaseTransactionRequestAaveWithdrawCallData](docs/BaseTransactionRequestAaveWithdrawCallData.md)
 - [BaseTransactionRequestAeroLiquidityProvisionCallData](docs/BaseTransactionRequestAeroLiquidityProvisionCallData.md)
 - [BaseTransactionRequestAeroLiquidityProvisionEthCallData](docs/BaseTransactionRequestAeroLiquidityProvisionEthCallData.md)
 - [BaseTransactionRequestAeroRemoveLiquidityCallData](docs/BaseTransactionRequestAeroRemoveLiquidityCallData.md)
 - [BaseTransactionRequestAeroRemoveLiquidityEthCallData](docs/BaseTransactionRequestAeroRemoveLiquidityEthCallData.md)
 - [BaseTransactionRequestAeroSwapEthForTokenCallData](docs/BaseTransactionRequestAeroSwapEthForTokenCallData.md)
 - [BaseTransactionRequestAeroSwapTokenForEthCallData](docs/BaseTransactionRequestAeroSwapTokenForEthCallData.md)
 - [BaseTransactionRequestAeroSwapTokensCallData](docs/BaseTransactionRequestAeroSwapTokensCallData.md)
 - [BaseTransactionRequestBuyExactlyCallData](docs/BaseTransactionRequestBuyExactlyCallData.md)
 - [BaseTransactionRequestIncreaseErc20AllowanceAnyCallData](docs/BaseTransactionRequestIncreaseErc20AllowanceAnyCallData.md)
 - [BaseTransactionRequestIncreaseErc20AllowanceCallData](docs/BaseTransactionRequestIncreaseErc20AllowanceCallData.md)
 - [BaseTransactionRequestSellExactlyCallData](docs/BaseTransactionRequestSellExactlyCallData.md)
 - [BaseTransactionRequestUniswapIncreaseLiquidityProvisionCallData](docs/BaseTransactionRequestUniswapIncreaseLiquidityProvisionCallData.md)
 - [BaseTransactionRequestUniswapMintLiquidityProvisionCallData](docs/BaseTransactionRequestUniswapMintLiquidityProvisionCallData.md)
 - [BaseTransactionRequestUniswapWithdrawLiquidityProvisionCallData](docs/BaseTransactionRequestUniswapWithdrawLiquidityProvisionCallData.md)
 - [BaseTransactionRequestWrapEthRequestCallData](docs/BaseTransactionRequestWrapEthRequestCallData.md)
 - [BuyExactlyCallData](docs/BuyExactlyCallData.md)
 - [Chain](docs/Chain.md)
 - [ContractName](docs/ContractName.md)
 - [EnsNameInfo](docs/EnsNameInfo.md)
 - [FeeEnum](docs/FeeEnum.md)
 - [GetErc20Allowance](docs/GetErc20Allowance.md)
 - [GetErc20Balance](docs/GetErc20Balance.md)
 - [GetLiquidityProvisionPositions](docs/GetLiquidityProvisionPositions.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [Image](docs/Image.md)
 - [IncreaseErc20AllowanceAnyCallData](docs/IncreaseErc20AllowanceAnyCallData.md)
 - [IncreaseErc20AllowanceCallData](docs/IncreaseErc20AllowanceCallData.md)
 - [InterestRateMode](docs/InterestRateMode.md)
 - [LPPositionsInfo](docs/LPPositionsInfo.md)
 - [Liquidity](docs/Liquidity.md)
 - [PercentageForWithdrawal](docs/PercentageForWithdrawal.md)
 - [Portfolio](docs/Portfolio.md)
 - [Position](docs/Position.md)
 - [RequestEnsDetails](docs/RequestEnsDetails.md)
 - [RequestUserAddress](docs/RequestUserAddress.md)
 - [SellExactlyCallData](docs/SellExactlyCallData.md)
 - [Token](docs/Token.md)
 - [TokenBalance](docs/TokenBalance.md)
 - [TokenInfo](docs/TokenInfo.md)
 - [UniswapBuyQuoteInfo](docs/UniswapBuyQuoteInfo.md)
 - [UniswapGetBuyQuote](docs/UniswapGetBuyQuote.md)
 - [UniswapGetPoolPrice](docs/UniswapGetPoolPrice.md)
 - [UniswapGetSellQuote](docs/UniswapGetSellQuote.md)
 - [UniswapIncreaseLiquidityProvisionCallData](docs/UniswapIncreaseLiquidityProvisionCallData.md)
 - [UniswapMintLiquidityProvisionCallData](docs/UniswapMintLiquidityProvisionCallData.md)
 - [UniswapPoolPrice](docs/UniswapPoolPrice.md)
 - [UniswapSellQuoteInfo](docs/UniswapSellQuoteInfo.md)
 - [UniswapWithdrawLiquidityProvisionCallData](docs/UniswapWithdrawLiquidityProvisionCallData.md)
 - [UnsignedTransaction](docs/UnsignedTransaction.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)
 - [WrapEthRequestCallData](docs/WrapEthRequestCallData.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author

contact@compasslabs.ai


